@@ -1,6 +1,6 @@
 ### This file is part of 'EvaluateCore' package for R.
 
-### Copyright (C) 2018-2022, ICAR-NBPGR.
+### Copyright (C) 2018-2025, ICAR-NBPGR.
 #
 # EvaluateCore is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by
@@ -43,7 +43,6 @@
 #' \insertCite{hennink_interpretation_1990}{EvaluateCore}} } \item{McIntosh
 #' Diversity Index} \itemize{ \item{McIntosh Diversity Index (\mjseqn{D_{Mc}})
 #' \insertCite{mcintosh_index_1967,peet_measurement_1974}{EvaluateCore}} } }
-#' \loadmathjax
 #'
 #' @section Details: The diversity indices and the corresponding statistical
 #'   tests implemented in \code{diversity.evaluate.core} are as follows.
@@ -222,6 +221,9 @@
 #'   }
 #'
 #' @inheritParams chisquare.evaluate.core
+#' @param na.omit logical. If \code{TRUE}, missing values (\code{NA}) are
+#'   ignored and not included as a distinct factor level for computation.
+#'   Default is \code{TRUE}.
 #' @param base The logarithm base to be used for computation of Shannon-Weaver
 #'   Diversity Index (\mjseqn{I}). Default is 2.
 #' @param R The number of bootstrap replicates. Default is 1000.
@@ -325,7 +327,7 @@
 #' }
 #'
 diversity.evaluate.core <- function(data, names, qualitative, selected,
-                                    base = 2, R = 1000) {
+                                    base = 2, R = 1000, na.omit = TRUE) {
 
   # Checks
   checks.evaluate.core(data = data, names = names,
@@ -349,6 +351,18 @@ diversity.evaluate.core <- function(data, names, qualitative, selected,
 
   dataf$`[Type]` <- as.factor(dataf$`[Type]`)
 
+  if (!na.omit) {
+    dataf[, qualitative] <- lapply(dataf[, qualitative], function(x) {
+      if (any(is.na(x))) {
+        addNA(x)
+      } else {
+        x
+      }
+    })
+  }
+
+  dataf <- tibble::as_tibble(dataf)
+
   div.indices <- lapply(dataf[, !colnames(dataf) %in% c(names, "[Type]")],
                         function(x) {
                           diversity.test(ECx = x[dataf$`[Type]` == "EC"],
