@@ -1,6 +1,6 @@
 ### This file is part of 'EvaluateCore' package for R.
 
-### Copyright (C) 2018-2022, ICAR-NBPGR.
+### Copyright (C) 2018-2025, ICAR-NBPGR.
 #
 # EvaluateCore is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by
@@ -20,8 +20,8 @@
 if (getRversion() >= "2.15.1")  {
   utils::globalVariables(
     c(
-      "..prop..", "PC", "Proportion of Variance", "Trait", "Ty", "quantitative",
-      "value", "x", "y", "lower", "upper"
+      "PC", "Proportion of Variance", "Trait", "Ty", "quantitative",
+      "value", "x", "y", "lower", "upper", "prop", "[Type]"
     )
   )
 }
